@@ -50,15 +50,15 @@ using namespace Rcpp;
 //' @export
 // [[Rcpp::export]]
 List simonBayesAnalysis(
-    const int nstrata,
-    const IntegerVector& r,
-    const IntegerVector& n,
-    const double lambda,
-    const double gamma,
-    const double phi,
-    const double plo) {
+    const int nstrata = NA_INTEGER,
+    const IntegerVector& r = NA_INTEGER,
+    const IntegerVector& n = NA_INTEGER,
+    const double lambda = NA_REAL,
+    const double gamma = NA_REAL,
+    const double phi = NA_REAL,
+    const double plo = NA_REAL) {
 
-  if (R_isnancpp(nstrata)) {
+  if (nstrata == NA_INTEGER) {
     stop("nstrata must be provided");
   }
 
@@ -304,7 +304,7 @@ List simonBayesSim(
     const NumericVector& p = NA_REAL,
     const NumericVector& accrualTime = 0,
     const NumericVector& accrualIntensity = NA_REAL,
-    const NumericVector& stratumFraction = NA_INTEGER,
+    const NumericVector& stratumFraction = 1,
     const double lambda = NA_REAL,
     const double gamma = NA_REAL,
     const double phi = NA_REAL,
@@ -370,10 +370,6 @@ List simonBayesSim(
     stop("plo must be provided");
   }
 
-  if (R_isnancpp(plo)) {
-    stop("plo must be provided");
-  }
-
   if (R_isnancpp(T)) {
     stop("T must be provided");
   }
@@ -402,7 +398,7 @@ List simonBayesSim(
     stop("T must lie between 0 and 1");
   }
 
-  if (R_isnancpp(maxSubjects)) {
+  if (maxSubjects == NA_INTEGER) {
     stop("maxSubjects must be provided");
   }
 
@@ -509,7 +505,8 @@ List simonBayesSim(
       if (open[j]) {
         arrivalTime[k] = enrollt;
         stratum[k] = j+1;
-        y[k] = R::rbinom(1, p[j]);
+        u = R::runif(0,1);
+        y[k] = u < p[j] ? 1 : 0;
 
         // update the number of subjects and responders in the stratum
         n[j] = n[j] + 1;
@@ -570,7 +567,7 @@ List simonBayesSim(
 
 
         // stop the trial if all strata are closed or max subjects reached
-        if (is_true(all(open==0)) || (k == maxSubjects)) {
+        if (is_true(all(open == 0)) || (k == maxSubjects)) {
           iterationNumber[iter] = iter+1;
           N[iter] = k;
           nact[iter] = nactive;
